function Result = CalcApparentKappa(Param,Const,Result)
% Calculate apparent kappa using Khler theory




% Surfactant parameters
Gamma_mol_per_m2 = Param.Gamma_mol_per_m2;
K = Param.K;
Sigma_min_J_per_m2 = Param.Sigma_min_J_per_m2;
A_H2O_m = 4 * 18.02e-6 * Const.Sigma_H2O_J_per_m2...
    /(Const.R_J_per_mol_K * Param.T_K);
% "A" parameter for Kelvin effect, water surface tension case


% Parameters
IntKappa_2D = Result.IntrinsicKappa_2D;
MolarVol_org_m3_per_mol = 18.02e-6 ./ IntKappa_2D;
OrgPMvolFrac_2D = Result.OrgPMvolFrac_2D;
O2CBasis = Param.O2CBasis;
nO2CBasis = size(O2CBasis,1);
nCStarBasis = size(IntKappa_2D,2);
Ddry_nm = Param.Ddry_nm; % dry particle diameter
Ddry_m = Ddry_nm * 1e-9;
InorgVolFrac = Param.InorgSeed_VolFrac;  % Volume fraction of inorganic seed particles
InorgKappa = Param.InorgKappa;  % Inorganic seed kappa
%OrgPMvol_m3_2D = OrgPMvolFrac_2D * pi/6 * Ddry_m^3;
epsilon = OrgPMvolFrac_2D * (1 - InorgVolFrac); % Rename for readability


% Calculate solubility basis using Kuwata et al. (2013) parameterization.
% lnC = 20 [ (O/C)^0.402 - 1]

lnC = 20*(((O2CBasis).* Param.O2CBasis_Factor_rand') .^0.402 - 1); % Randomizied for Monte Carlo. By default no change (1).
C_v_per_v = exp(lnC); % Volume based solubility, vol/vol
C_v_per_v_2D = repmat(C_v_per_v,1,nCStarBasis); % copy into 2D


% Make Khler curve
Nbins = 100;
Dmax_m = 5000e-9;
D_m = logspace(log10(Ddry_m),log10(Dmax_m),Nbins)';

% Create arrays
S = zeros(Nbins,1); % Saturation ratio (-)
S_solubilityOnly = zeros(Nbins,1); % Consider solubility but neglect surface activity
Fbulk = zeros(Nbins,nO2CBasis,nCStarBasis); % Solute phase fraction, bulk: dissolved aqueous
Fsurf = zeros(Nbins,nO2CBasis,nCStarBasis); % Solute phase fraction, surf: surface
Sigma_withPartition_J_per_m2 = zeros(Nbins,1);% Surface tension considering full partitioning
Kappa_withPartition = zeros(Nbins,1);
Fbulk_Vol_weighted = zeros(Nbins,1); % Fbulk of all solutes
Fsurf_Vol_weighted = zeros(Nbins,1); % Fsurf of all solutes
MolFrac_total_org_bulk = zeros(Nbins,1);
% Mole fraction of total solute in bulk.  Since structure-dependence of
% surface activity is not available, all compounds are assumed to have
% the same Gamma and K parameters.  All solutes' moles are added up and
% their total mole fraction in aqueous solution is used to calculate
% surface tension depression.

Kappa_solubilityOnly = zeros(Nbins,1);
Fcore_solubilityOnly = zeros(Nbins,1);
Fcore_solubilityOnly(1) = 1;
Fcore_solubilityOnly_2D = zeros(nO2CBasis,nCStarBasis);
Fsurf_temp_2D = zeros(nO2CBasis,nCStarBasis);



% Calculate saturation ratio, S, at each droplet size
for iD = 2:Nbins
    
    nw_mol = pi/6 * (D_m(iD)^3 - Ddry_m^3) / (18.02e-6); % water mol
    
    % Solubility-only loop as the initial step
    for iO2CBasis = 1:nO2CBasis
        for iCStarBasis = 1:nCStarBasis
            
            HGF = D_m(iD) / Ddry_m;
            xi = (HGF^3 - 1) ...
                * C_v_per_v_2D(iO2CBasis,iCStarBasis) * Param.C_v_per_v_Factor_rand (iO2CBasis)...
                /epsilon(iO2CBasis,iCStarBasis);
            
            if xi < 1
                H_xi = xi;
            else
                H_xi = 1;
            end
            
            Kappa_solubilityOnly(iD) =  Kappa_solubilityOnly(iD) ...
                + epsilon(iO2CBasis,iCStarBasis)...
                * IntKappa_2D(iO2CBasis,iCStarBasis) * H_xi;
            
            Fcore_solubilityOnly_2D(iO2CBasis,iCStarBasis)...
                = 1 - H_xi; % Undissolved fraction for each bin
            
            Fcore_solubilityOnly(iD) = Fcore_solubilityOnly(iD) ...
                + epsilon(iO2CBasis,iCStarBasis)...
                * (1 - H_xi);
        end
    end
    
    % Temporary values of bulk and core fraction. To be iterated later.
    Fbulk_temp_2D = 1 - Fcore_solubilityOnly_2D;
    Fcore_temp_2D = Fcore_solubilityOnly_2D;
    nbulk_mol_temp_2D = Fbulk_temp_2D .* epsilon...
        * pi/6 * Ddry_m^3 ./ MolarVol_org_m3_per_mol ;
    nbulk_mol_temp = sum(sum(nbulk_mol_temp_2D));
    
    
    % As long as undissolved core exist, Fbulk equals solubility only case.
    % Surface partition is compensated by reduction in Fcore.
    while 1
        
        temp_Result = CalcBulkFrac_mol_based(nbulk_mol_temp,nw_mol,D_m(iD),Gamma_mol_per_m2,K);
        Fsurf_temp_2D_new = 1 - Fcore_temp_2D - temp_Result.BulkFrac .* (1 - Fcore_temp_2D);
        AdditionalCoreDissolution_2D = (Fsurf_temp_2D_new - Fsurf_temp_2D)/2;
        % Reduce dissolution to minimuze oscillation
        
        Fcore_temp_2D_new = Fcore_temp_2D - AdditionalCoreDissolution_2D;
        Fcore_temp_2D_new(Fcore_temp_2D_new < 0) = 0; % Fcore cannot be negative
        AdditionalCoreDissolution_2D = Fcore_temp_2D - Fcore_temp_2D_new;
        Fbulk_temp_2D_new = Fbulk_temp_2D + AdditionalCoreDissolution_2D;
        nbulk_mol_temp_2D_new = Fbulk_temp_2D_new .* epsilon...
            * pi/6 * Ddry_m^3 ./ MolarVol_org_m3_per_mol ;
        nbulk_mol_temp_new = sum(sum(nbulk_mol_temp_2D_new));
        
        if ((nbulk_mol_temp_new - nbulk_mol_temp)^2)^.5/nbulk_mol_temp < 0.001
            %update
            nbulk_mol_temp = nbulk_mol_temp_new;
            Fcore_temp_2D = Fcore_temp_2D_new;
            Fsurf_temp_2D = Fsurf_temp_2D_new;
            
            break
        end
        
        %update
        nbulk_mol_temp = nbulk_mol_temp_new;
        Fbulk_temp_2D = Fbulk_temp_2D_new;
        Fcore_temp_2D = Fcore_temp_2D_new;
        Fsurf_temp_2D = Fsurf_temp_2D_new;
        
        
        % Unreasonable number may appear very rarely in Monte Carlo
        % simulation
        if isnan(nbulk_mol_temp)
            break
        end
        
        
    end
    
    Fbulk_Vol_weighted(iD) = sum(sum(Fbulk_temp_2D .* epsilon));
    Fsurf_Vol_weighted(iD) = sum(sum(Fsurf_temp_2D .* epsilon));
    %Fcore_Vol_weighted(iD) = sum(sum(Fcore_temp_2D .* epsilon));
    Kappa_withPartition(iD) = sum(sum(IntKappa_2D .* epsilon .* Fbulk_temp_2D));
    
    
    MolFrac_total_org_bulk(iD) = nbulk_mol_temp...
        /(nw_mol + nbulk_mol_temp);
    
    Sigma_withPartition_J_per_m2(iD) = ...
        Const.Sigma_H2O_J_per_m2 ...
        - Const.R_J_per_mol_K * Param.T_K...
        * Gamma_mol_per_m2 * log(1 + K * MolFrac_total_org_bulk(iD));
    
    
    % Set minimum surface tension
    if Sigma_withPartition_J_per_m2(iD) < Sigma_min_J_per_m2
        Sigma_withPartition_J_per_m2(iD) = Sigma_min_J_per_m2;
    end
    
    % "A" parameter for Kelvin effect
    A_withPartition_m = 4 * 18.02e-6 * Sigma_withPartition_J_per_m2(iD)...
        /(Const.R_J_per_mol_K * Param.T_K);
    
    
    % Add inorganic portion
    Kappa_withPartition(iD) = Kappa_withPartition(iD) + InorgVolFrac * InorgKappa; % Assume soluble inorganic
    Kappa_solubilityOnly(iD) = Kappa_solubilityOnly(iD) + InorgVolFrac * InorgKappa; % Assume soluble inorganic
    
    
    
    S(iD) = (D_m(iD)^3 - Ddry_m^3) / ...
        (D_m(iD)^3 - Ddry_m^3 * (1 - Kappa_withPartition(iD)))...
        * exp(A_withPartition_m /D_m(iD));
    
    
    % Solubility-only case for comparison
    S_solubilityOnly(iD) = (D_m(iD)^3 - Ddry_m^3) / ...
        (D_m(iD)^3 - Ddry_m^3 * (1 - Kappa_solubilityOnly(iD)))...
        * exp(A_H2O_m /D_m(iD));
    
    
    
    
end

%disp('Kohler curve calculation done')

[Sc,MaxIndex] = max(S); % Critical saturation ratio
D_critical_m = D_m(MaxIndex);
ApparentKappa = Sc_and_Ddry_2_kappa(Sc,A_H2O_m,Ddry_m);
% Kappa to be determined experimentally assuming water surface tension


% Solubility-only case for comparison
[Sc_solubilityOnly,MaxIndex_solubilityOnly] = max(S_solubilityOnly); % Critical saturation ratio
D_critical_m_solubilityOnly = D_m(MaxIndex_solubilityOnly);
ApparentKappa_solubilityOnly = Sc_and_Ddry_2_kappa(Sc_solubilityOnly,A_H2O_m,Ddry_m);
% Kappa to be determined experimentally assuming water surface tension




Result.ApparentKappa = ApparentKappa;
Result.ApparentKappaOrg = (Result.ApparentKappa - InorgKappa * InorgVolFrac) / ...
    (1 - InorgVolFrac); % Calculate organic kappa based on volume balance
Result.ApparentKappa_solubilityOnly = ApparentKappa_solubilityOnly;
Result.ApparentKappaOrg_solubilityOnly = (Result.ApparentKappa_solubilityOnly...
    - InorgKappa * InorgVolFrac) / ...
    (1 - InorgVolFrac); % Calculate organic kappa based on volume balance
Result.Sc = Sc;
Result.Sc_solubilityOnly = Sc_solubilityOnly;


Result.SatRatio = S; % Khler curve considering 2D-VBS
Result.S_solubilityOnly = S_solubilityOnly; % no consideration of surface activity

Result.D_m = D_m; % Wet diameter vector
Result.Fbulk = Fbulk;% 3D data
Result.Fsurf = Fsurf;

Result.Fbulk_Vol_weighted = Fbulk_Vol_weighted / (1 - InorgVolFrac);% Vol weighted sum of organic solute fraction in bulk aqueous phase
Result.Fsurf_Vol_weighted = Fsurf_Vol_weighted / (1 - InorgVolFrac);
Result.Fcore_Vol_weighted = 1 - Result.Fbulk_Vol_weighted - Result.Fsurf_Vol_weighted;
Result.Fcore_solubilityOnly = Fcore_solubilityOnly;
Result.Fbulk_solubilityOnly = 1 - Fcore_solubilityOnly;
Result.Sigma_withPartition_J_per_m2 = Sigma_withPartition_J_per_m2 ;

Result.D_critical_m = D_critical_m;
Result.D_critical_m_solubilityOnly = D_critical_m_solubilityOnly;
Result.C_v_per_v_2D = C_v_per_v_2D; % solubility
end