function Results = CalcCoreSurfaceFraction(D_m,Ddry_m,MolarVol_org_m3_per_mol,...
    Epsilon,Solubility_v_per_v,Gamma_mol_per_m2,K)

% Calculates undissolved fraction (Fcore) based on solubility and
% surface fraction (Fsurf) based on bulk-surface partitioning

g = D_m / Ddry_m; % growth factor
Area_m2 = pi * D_m^2;
nw_mol = pi/6 * (D_m^3 - Ddry_m^3) / (18.02e-6); % water mol
niT_mol = pi/6 * Ddry_m^3 * Epsilon / MolarVol_org_m3_per_mol; % total org solute i
Kappa_intrinsic = 18.02e-6 / MolarVol_org_m3_per_mol; % Intrinsic kappa, no-partition

% initialize
Fcore = 1;
Fsurf = 0;

if Epsilon ==0 % no solute in the 2D-VBS bin
    Fbulk =0;
    Fsurf = 0;
    Fcore = 0;
    MolFrac_i_bulk = 0;
    
elseif g == 0 % Dry particle
    Fbulk =0;
    Fsurf = 0;
    Fcore = 1;
    MolFrac_i_bulk = 0;
    
else
    
    
    % Iterate core-bulk equiliriuam and bulk-surface equilibrium
    while 1
        
        % Fbulk is determined by solubility when undissolved core exist.
        % Let core dissolve, neglect surface (Petters and Kreidenweis, 2008, Eq.8)
        
        Fbulk = Solubility_v_per_v * (g^3 - 1)/ Epsilon ;
        % epsilon is volume fraction of solute i in total solute
        
        
        if Fbulk > 1
            Fcore = 0; % entirely dissolved
            % Solve as only bulk-surface partitioning problem (Topping 2010)
            FullyDissolvedResults = CalcBulkFrac(Ddry_m,D_m,Epsilon,Kappa_intrinsic,Gamma_mol_per_m2,K);
            Fbulk = FullyDissolvedResults.BulkFrac;
            Fsurf = 1 - Fbulk;
            MolFrac_i_bulk = FullyDissolvedResults.x_bulk_solute;
            break
        end
        
        Fcore = 1 - Fbulk - Fsurf;
        
        if Fcore < 0.001
            Fcore = 0;
            % Solve as only bulk-surface partitioning problem (Topping 2010)
            FullyDissolvedResults = CalcBulkFrac(Ddry_m,D_m,Epsilon,Kappa_intrinsic,Gamma_mol_per_m2,K);
            Fbulk = FullyDissolvedResults.BulkFrac;
            Fsurf = 1 - Fbulk;
            MolFrac_i_bulk = FullyDissolvedResults.x_bulk_solute;
            break
        end
        
        
        % The effect of core is modeled as reduction in epsilon by (1 - Fcore).
        % Calculate bulk fraction as above after removing Fcore.
        % The resulting Fbulk and Fsurf would add up to 1, but in reality
        % it should add up to (1 - Fcore).
        % Therefore, the output Fbulk should be corrected by (1 - Fcore). 
        
        Epsilon_temp = Epsilon * (1 - Fcore);
        CoreRemainingResults = CalcBulkFrac(Ddry_m,D_m,Epsilon_temp,Kappa_intrinsic,Gamma_mol_per_m2,K);
        Fbulk_new = CoreRemainingResults.BulkFrac * (1 - Fcore);
        Fsurf_new = (1 - Fbulk_new) * (1 - Fcore);
        MolFrac_i_bulk = CoreRemainingResults.x_bulk_solute; % no need for correction here
        MassTransfer = Fsurf_new - Fsurf;
        Fcore_new = Fcore - MassTransfer; % transferred solute should be replenished by the core
        
        
        
        %         % Bulk-surface partitioning (Topping 2010), neglect core
        %         niBS_mol_loop = (Fbulk + Fsurf) * niT_mol; % Only consider bulk + surface solute
        %
        %         a_mol = Area_m2 * Gamma_mol_per_m2 * K...
        %             - nw_mol * K...
        %             - niBS_mol_loop * K;
        %
        %         b_mol = niBS_mol_loop * K...
        %             - niBS_mol_loop - nw_mol...
        %             - Area_m2 * Gamma_mol_per_m2 * K;
        %
        %         MolFrac_i_bulk = (-b_mol - (b_mol.^2 - 4 * a_mol...
        %             * niBS_mol_loop).^0.5) ./ (2 * a_mol);
        %
        %         niB_mol_loop = MolFrac_i_bulk /(1 - MolFrac_i_bulk) * nw_mol;
        %         % Treat as if binary solution (Topping 2010, Eq.18,19).
        %         % Express mole fraction of i in i - water binary solution
        %         % and solve for bulk solute mole.
        %
        %         Fbulk_new = niB_mol_loop / niT_mol;
        %
        %         Fsurf = 1 - Fcore - Fbulk_new;
        %
        %
        %         Fbulk = Fbulk_new;
        %
        
        if (Fcore_new - Fcore)^2 < 1e-6 % convergence criteria
 %           Fbulk = Fbulk_new;
            break
        end
  

        Fsurf = Fsurf_new;
        Fcore = Fcore_new;
        %Fbulk is fixed as long as core exists
      
        
    end
    
end


Results.Fbulk = Fbulk;
Results.Fcore = Fcore;
Results.Fsurf = Fsurf;
Results.MolFrac_i_bulk = MolFrac_i_bulk; % Solution mol fraction i



end


