function Result = CalcIntrinsicKappa2DVBS(Param,Const)
% Calculate Intrinsic kappa based on 2D-VBS

% Rename for readability
OM_2DVBS = Param.OM_2DVBS; %OM (total = gas + PM) mass distribution in 2D space
O2CBasis = Param.O2CBasis;
CStarBasis = Param.CStarBasis;
VBS = Param.VBS; % 1D VBS
b0 = Const.SIMPOL_b0; % SIMPOL parameter for volatility calculation, Pankow and Asher 2008
bc = Const.SIMPOL_bc; % SIMPOL parameter for volatility calculation, Pankow and Asher 2008
b_carbonyl = Const.SIMPOL_b_carbonyl; % SIMPOL parameter for volatility calculation, Pankow and Asher 2008
b_alcohol = Const.SIMPOL_b_alcohol; % SIMPOL parameter for volatility calculation, Pankow and Asher 2008

nO2CBins = size(OM_2DVBS,1); % number of O/C bins
nCStarBins = size(OM_2DVBS,2); % number of C* bins

% Initialize
nC_2D = zeros(nO2CBins,nCStarBins); % number of carbon in the 2D space
nH_2D = zeros(nO2CBins,nCStarBins); % number of hydrogen in the 2D space
Kappa_int_2D = zeros(nO2CBins,nCStarBins); % Intrinsic kappa from Raoult's law
Density_2D = zeros(nO2CBins,nCStarBins); % Organic density
OrgPMvol_2D_um3_per_cm3 = zeros(nO2CBins,nCStarBins); % Organic PM volume is needed to calculate volume-weighted kappa


% Calculate aerosol partitioning using 1D-VBS
partCoeff = partitionAerosol(CStarBasis,VBS);
partCoeff2D = repmat(partCoeff,nO2CBins,1);
    % Make 2D copy of the partition coefficient.
    % Partition coeff is constant in O/C dimension

OrgPM_2DVBS = OM_2DVBS .* partCoeff2D;
    % Multiply the partition coefficient with OM total mass in each bin 
    % to calculate condensed mass.


% Alpha conversion term: C*[ug/m3] = (alpha)*Psat[atm]
alpha = Param.alpha;

% Calculate number of carbon in 2D space
% Assumption 1: H/C = 2 - O/C (Donahue et al., 2012).
%       Note this is simpler than Daumit et al. (2013) who used H/C
%       to constrain carbonyl:alcohol ratios.
% Assumption 2: nO = n_carbonyl + n_alcohol (Donahue et al., 2012)
% Assumption 3: n_carbonyl = n_alcohol (Donahue et al., 2012)
% Using SIMPOL (Daumit et al. Faraday Disc. 2013, Eq.4):
% log C* = log(alpha) + b0 + bc * nC + b_carbonyl * n_carbonyl + b_alcohol
% * n_alcohol.
% Using the assumptions 2, 3 and solving for nC:
% nC = {log C* - log(alpha) - b0} / {bc + 0.5*(b_carbonyl + b_alcohol)*O/C}


% Calculate nC, nH, intrinsic Kappa in 2D space.
for iO2CBins = 1:nO2CBins
    for iCStarBins = 1:nCStarBins
        
        nC_2D(iO2CBins,iCStarBins) = (log10(CStarBasis(iCStarBins)) - log10(alpha) - b0) / ...
            (bc + 0.5*(b_carbonyl + b_alcohol)*O2CBasis(iO2CBins));
        nH_2D(iO2CBins,iCStarBins) = (2 - O2CBasis(iO2CBins)) * ...
            nC_2D(iO2CBins,iCStarBins); % Assumption 1
        
        nC = nC_2D(iO2CBins,iCStarBins); % Rename for readability
        nH = nH_2D(iO2CBins,iCStarBins);
        nO = O2CBasis(iO2CBins) * nC;
        
        % Calculate Org PM volume concentration because kappa additivity is
        % based on volume
        Density_2D(iO2CBins,iCStarBins) = CalcDensity(nC,nH,nO);
        OrgPMvol_2D_um3_per_cm3(iO2CBins,iCStarBins)  = OrgPM_2DVBS(iO2CBins,iCStarBins) /...
            Density_2D(iO2CBins,iCStarBins);

        
        % Recalculate nC, nH, nO considering random distribution in Monte
        % Carlo.  Randomization is done after density calculation so that
        % partitioning results are not affected. This only affects
        % intrinsic Kappa.
        
        nC_2D(iO2CBins,iCStarBins) = (log10(CStarBasis(iCStarBins)*Param.CstarBasis_Factor_rand(iCStarBins)) - log10(alpha) - b0) / ...
            (bc + 0.5*(b_carbonyl + b_alcohol)*O2CBasis(iO2CBins) * Param.O2CBasis_Factor_rand(iO2CBins));
        nH_2D(iO2CBins,iCStarBins) = (2 - O2CBasis(iO2CBins)* Param.O2CBasis_Factor_rand(iO2CBins)) * ...
            nC_2D(iO2CBins,iCStarBins); % Assumption 1
        
        nC = nC_2D(iO2CBins,iCStarBins); % Rename for readability
        nH = nH_2D(iO2CBins,iCStarBins);
        nO = O2CBasis(iO2CBins) * Param.O2CBasis_Factor_rand(iO2CBins)* nC;
        
        Kappa_int_2D(iO2CBins,iCStarBins) = CalcKappaRaoult(nC,nH,nO);

        
        
    end
end


% Calculate organic PM volume and mass fraction
OrgPMvolFrac_2D = OrgPMvol_2D_um3_per_cm3 / sum(OrgPMvol_2D_um3_per_cm3(:));
OrgPMmassFrac_2D = OrgPM_2DVBS / sum(OrgPM_2DVBS(:));


% Calculate volume weighted intrinsic kappa of the mixture
VolumeWeightedKappa_2D = Kappa_int_2D .* OrgPMvolFrac_2D;

% Calculate overall O/C, H/C and C*, which are equivalent to experimentally
% determined values (e.g., AMS Elemental analysis, Thermodenuder)

O2C_2D = repmat(O2CBasis,1,nCStarBins); % copy O/C in 2D
H2C_2D = 2 - O2C_2D; % Heald et al.
CStar_2D = repmat(CStarBasis,nO2CBins,1); % copy C* in 2D
log10CStar_2D = log10(CStar_2D);
MassWeightedO2C_2D = OrgPMmassFrac_2D .* O2C_2D;
MassAveragedO2C = sum(MassWeightedO2C_2D(:)); % mass-averaged O2C
MassWeightedH2C_2D = OrgPMmassFrac_2D .* H2C_2D;
MassAveragedH2C = sum(MassWeightedH2C_2D(:));
MassWeightedCStar_2D = OrgPMmassFrac_2D .* CStar_2D;
MassWeightedlog10CStar_2D = OrgPMmassFrac_2D .* log10CStar_2D;
MassAveragedCStar = sum(MassWeightedCStar_2D(:));
MassAveragedlog10CStar = sum(MassWeightedlog10CStar_2D(:));
MassAveragednC = (log10(MassAveragedCStar) - log10(alpha) - b0) / ...
    (bc + 0.5*(b_carbonyl + b_alcohol)*MassAveragedO2C); 
    % Calculate nC from the bulk composition
BulkOrgSolubility = exp(20*(MassAveragedO2C^0.402 - 1));
    % Calculate organic solubility from the bulk O/C
IntrinsicKappa_from_bulk_composition = CalcKappaRaoult(...
    MassAveragednC,...
    MassAveragednC * MassAveragedH2C,...
    MassAveragednC * MassAveragedO2C);
    % Calculate kappa by applying Raoult's law to bulk compositions.
    % This is different from summation of volume weighted kappa in each bin.


% Output results
Result.OrgPMmass_ug_m3 = sum(OrgPM_2DVBS(:)); 
    % Mass of condensed organics (ug/m3)
    % Note mass of reacted alpha-pinene (ug/m3) is specified in Param
Result.IntrinsicKappa = sum(VolumeWeightedKappa_2D(:)); % volume averaged value
Result.IntrinsicKappa_2D = Kappa_int_2D; % Spread out in 2D
Result.IntrinsicKappa_from_bulk_composition = IntrinsicKappa_from_bulk_composition; 
    % From bulk O/C, H/C, nC
Result.OrgPMvolFrac_2D = OrgPMvolFrac_2D;
Result.MassAveragedO2C = MassAveragedO2C;
Result.MassAveragedH2C = MassAveragedH2C;
Result.MassAveragednC = MassAveragednC;
Result.MassAveragedCStar = MassAveragedCStar;
Result.MassAveragedlog10CStar = MassAveragedlog10CStar;
Result.BulkOrgSolubility = BulkOrgSolubility;

end