function EvaluateSFTparam()
% Evaluate effects of surface activity parameters:
%  - Maximum surface excess (Gamma)
%  - Adsorption coefficient (K)

Gamma_mol_per_m2 = 2e-6;
K = 2e4; % adsorption coefficient, molH2O/molSFT


Const = GetConst;
Param = SetParam;

Ddry_m = 100e-9;
SigmaMin_J_per_m2 = 0.04; % arbiturary chosen minimum surface tension

% Make droplet arrays
Dmax_m = 5000e-9;
D_m = logspace(log10(Ddry_m),log10(Dmax_m),100)';


Kappa_NP = 0.1; % no partition kappa
Epsilon = 0.01;
Results = CalcBulkFrac(Ddry_m,D_m,Epsilon,Kappa_NP,Gamma_mol_per_m2,K);


% Kohler curve calculation
MolarVol_m3_per_mol_H2O = 18.02e-3 /(1000);

A_m_w = 4 * MolarVol_m3_per_mol_H2O * Const.Sigma_H2O_J_per_m2...
    /(Const.R_J_per_mol_K * Param.T_K); % assuming water surface tension

Sigma_J_per_m2_NP = Const.Sigma_H2O_J_per_m2...
    - Const.R_J_per_mol_K * Param.T_K ... % NP: no partitioning
    * Gamma_mol_per_m2...
    * log(1 + K * Results.n_mol_solute ./(Results.n_mol_solute + Results.n_mol_H2O));
Sigma_J_per_m2_NP ... % NP: no partitioning
    (Sigma_J_per_m2_NP < SigmaMin_J_per_m2)=...
    SigmaMin_J_per_m2; % limit sigma minimum

A_m_NP = 4 * MolarVol_m3_per_mol_H2O .* Sigma_J_per_m2_NP...
    /(Const.R_J_per_mol_K * Param.T_K);


Sigma_J_per_m2_P = Const.Sigma_H2O_J_per_m2...
    - Const.R_J_per_mol_K * Param.T_K ...
    * Gamma_mol_per_m2...
    * log(1 + K * Results.x_bulk_solute);
Sigma_J_per_m2_P ... % P: with partitioning
    (Sigma_J_per_m2_P < SigmaMin_J_per_m2)=...
    SigmaMin_J_per_m2; % limit sigma minimum


A_m_P = 4 * MolarVol_m3_per_mol_H2O .* Sigma_J_per_m2_P...
    /(Const.R_J_per_mol_K * Param.T_K);

Kappa_P = Results.BulkFrac * Kappa_NP;

S_aNP_sigmaNP = (D_m.^3 - Ddry_m^3) ./ (D_m.^3 - Ddry_m^3 * (1-Kappa_NP))...
    .* exp(A_m_NP./D_m);

S_aNP_sigmaP = (D_m.^3 - Ddry_m^3) ./ (D_m.^3 - Ddry_m^3 * (1-Kappa_NP))...
    .* exp(A_m_P./D_m);

S_aP_sigmaP = (D_m.^3 - Ddry_m^3) ./ (D_m.^3 - Ddry_m^3 * (1-Kappa_P))...
    .* exp(A_m_P./D_m);

S_aNP_sigmaW = (D_m.^3 - Ddry_m^3) ./ (D_m.^3 - Ddry_m^3 * (1-Kappa_NP))...
    .* exp(A_m_w./D_m); % no partition in Raoult, water sigma



Fig1 = figure;
LineWidth = 2;
FontSize = 15;
Dmax_m = 2e-6;
Fig1.Units = 'normalized';
Fig1.Position = [0.5 0.3 0.2 0.6];
ax1 = subplot(3,1,1);
ax2 = subplot(3,1,2);
ax3 = subplot(3,1,3);
linkaxes([ax1,ax2,ax3],'x')
xlabel(ax3,'Wet diameter [\mum]')

plot(ax1,D_m * 1e6, S_aNP_sigmaNP,'ro','LineWidth',LineWidth)
ylabel(ax1,'Saturation ratio')
ylabel(ax2,'Fraction of solute in bulk')
ylabel(ax3,'Surface tension [J m^{-2}]')

ylim(ax1,[1 1.005])
ylim(ax2,[0 1])
ylim(ax3,[SigmaMin_J_per_m2 0.075])

xlim(ax1,[Ddry_m * 1e6 Dmax_m * 1e6])

hold (ax1,'on')
hold (ax2,'on')
hold (ax3,'on')


ax1.FontSize = FontSize;
ax1.LineWidth = LineWidth;
ax2.FontSize = FontSize;
ax2.LineWidth = LineWidth;
ax3.FontSize = FontSize;
ax3.LineWidth = LineWidth;
box(ax2,'on')
box(ax3,'on')


plot(ax1,D_m * 1e6, S_aNP_sigmaP,'bo','LineWidth',LineWidth)
plot(ax1,D_m * 1e6, S_aP_sigmaP,'ko','LineWidth',LineWidth)
plot(ax1,D_m * 1e6, S_aNP_sigmaW,'go','LineWidth',LineWidth)
legend(ax1,'aw_{No partitioning}\sigma_{ws No partitioning}',...
    'aw_{No partitioning}\sigma_{ws Partitioning}',...
    'aw_{Partitioning}\sigma_{ws Partitioning}',...
    'aw_{No partitioning}\sigma_{w}')

plot(ax2,D_m * 1e6, Results.BulkFrac,'mo','LineWidth',LineWidth);
plot(ax3,[Ddry_m * 1e6 Dmax_m * 1e6],...
    [Const.Sigma_H2O_J_per_m2 Const.Sigma_H2O_J_per_m2], 'g-'...
    ,'LineWidth',LineWidth);
plot(ax3,D_m * 1e6, Sigma_J_per_m2_P,'bx','LineWidth',LineWidth);
plot(ax3,D_m * 1e6, Sigma_J_per_m2_NP,'rx','LineWidth',LineWidth);

legend(ax3,'\sigma_{W}',...
    '\sigma_{ws Partitioning}',...
    '\sigma_{ws No partitioning}','Location','southeast')


end