function Results = Fig1()

% Calculate Kohler curves for pure compounds studied in Petters et al.
% 2016. Petters et al. (PKZ16) used UNIFAC. 
% This study assume ideal solution with estimated solubility.
% Surface activity data is used when available.

close all
Const = GetConst;
Param = SetParam;

% Petters, M. D., S. M. Kreidenweis, and P. J. Ziemann. 2016.
% Prediction of cloud condensation nuclei activity for organic
% compounds using functional group contribution methods,
% Geosci. Model Dev. 9:111-124.

PKZ16 = [ ...
    %C	H	O	N	Ddry_nm	Kappa_Obs	Kappa_UNIFAC Gamma_mol_per_m2 K
14	28	4	0	264	9.20E-04	8.30E-05	nan	nan			
14	28	5	0	123	2.80E-02	8.50E-05	nan	nan			
4	4	4	0	100	3.55E-01	2.20E-01	nan	nan	% Maleic		% assume 100 nm
4	6	4	0	100	2.35E-01	2.00E-01	1.35E-06	3.72E-02	% Succinic	% Lee and Hildemann 2014	% assume 100 nm
5	6	5	0	100	3.10E-01	1.70E-01	nan	nan	% alpha-ketoglutaric acid		% assume 100 nm
5	8	4	0	100	1.07E-01	1.70E-01	5.00E-07	1.05E+03	% Glutaric	% Topping 2010	
6	10	4	0	200	1.00E-02	1.40E-01	nan	nan	% Adipic		
7	12	4	0	100	1.50E-01	1.30E-01	nan	nan	% Pimelic		% assume 100 nm
9	16	4	0	113	4.00E-02	1.20E-02	nan	nan	% Azelaic		
10	16	3	0	115	5.00E-03	5.30E-05	2.60E-06	2.62E-04	% Cis-pinonic	% Topping 2010	
4	10	4	0	100	1.40E-01	2.10E-01	nan	nan			% assume 100 nm
6	12	6	0	100	1.70E-01	1.70E-01	nan	nan			% assume 100 nm
12	22	11	0	100	9.00E-02	1.10E-01	nan	nan			% assume 100 nm
18	32	16	0	100	5.00E-02	9.10E-02	nan	nan	];		% assume 100 nm	];	
% Surface activity parameters (Gamma, K) are included when available,
%  otherwise set to surface tension of water.


nCompound = size(PKZ16,1); % nunber of pure compounds in the list

HtoC = PKZ16(:,2)./PKZ16(:,1);
OtoC = PKZ16(:,3)./PKZ16(:,1);
Morg_kg_per_mol = (12 * PKZ16(:,1) + PKZ16(:,2) + 16 * PKZ16(:,3) + 14 * PKZ16(:,4))*1e-3;
Density_Kuwata_kg_per_m3 = 1000 * (12 + HtoC + 16 * OtoC)./...
    (7 + 5 * HtoC + 4.15 * OtoC);
MolarVol_org_m3_per_mol = Morg_kg_per_mol ./Density_Kuwata_kg_per_m3;
Kappa_Raoult_Kuwata = 18.02e-6 ./ MolarVol_org_m3_per_mol;
Gamma_mol_per_m2 = PKZ16(:,8);
K = PKZ16(:,9);

% Consider solubility
A_m_w = 4 * 18.02e-6 * Const.Sigma_H2O_J_per_m2...
    /(Const.R_J_per_mol_K * Param.T_K); % assuming water surface tension
nBins = 1000;

solubility_v_per_v = zeros(nCompound,1);
Dmin_m = 50e-9;
Dmax_m = 5000e-9;
D_m = logspace(log10(Dmin_m),log10(Dmax_m),nBins)';
S = zeros(nBins,nCompound);
Kappa_withPartition = zeros(nBins,nCompound); % Kappa keeps changing as partition shifts
Kappa_withPartition_CriticalPoint = zeros(nCompound,1); % Kappa at the point of activation
Sigma_withPartition = zeros(nBins,nCompound);
Fbulk = zeros(nBins,nCompound);
Fsurf = zeros(nBins,nCompound);
Fcore = zeros(nBins,nCompound);


for iComp = 1:nCompound 
    
    Ddry_m = PKZ16(iComp,5)*1e-9;    
    solubility_v_per_v(iComp) = exp(20*(OtoC(iComp)^0.402 - 1));
    epsilon = 1; % solute volume fraction = 1 for pure compounds
        
    for iBins = 1:nBins
        HGF = D_m(iBins) / Ddry_m;
        
        if D_m(iBins) <= Ddry_m            
            S(iBins,iComp) = 0;

        elseif isnan(Gamma_mol_per_m2(iComp))% Surface parameter not available
            xi = (HGF^3 - 1)* solubility_v_per_v(iComp)/epsilon; % Dissolved solute fraction
            % Ref Petters and Kreidenweis (2008)
            
            if xi < 1; H_xi = xi;
            else H_xi = 1; end  % Dissolved fraction cannot be more than 1

            Kappa_withPartition(iBins,iComp) = Kappa_Raoult_Kuwata(iComp) * H_xi;
            
            S(iBins,iComp) = (D_m(iBins)^3 - Ddry_m^3) / ...
                (D_m(iBins)^3 - Ddry_m^3 * (1 - Kappa_withPartition(iBins,iComp)))...
                * exp(A_m_w /D_m(iBins));% use water surface tension

            Sigma_withPartition(iBins,iComp) = Const.Sigma_H2O_J_per_m2;
            
        else
            
            PartitionResults = CalcCoreSurfaceFraction(D_m(iBins),Ddry_m,...
                MolarVol_org_m3_per_mol(iComp),epsilon,solubility_v_per_v(iComp),...
                Gamma_mol_per_m2(iComp),K(iComp)); % core-bulk-surface partition
            
            Fbulk(iBins,iComp) = PartitionResults.Fbulk;
            Fsurf(iBins,iComp) = PartitionResults.Fsurf;
            Fcore(iBins,iComp) = 1 - Fbulk(iBins,iComp) - Fsurf(iBins,iComp);
            MolFrac_i_bulk = PartitionResults.MolFrac_i_bulk; % solution mole fraction
            
            Sigma_withPartition_J_per_m2(iBins,iComp) = Const.Sigma_H2O_J_per_m2...
                - Const.R_J_per_mol_K * Param.T_K...
                * Gamma_mol_per_m2(iComp) ...
                * log(1 + K(iComp) * MolFrac_i_bulk);
            
            A_withPartition_m = 4 * 18.02e-6 * Sigma_withPartition_J_per_m2(iBins,iComp)...
                /(Const.R_J_per_mol_K * Param.T_K);
            
            Kappa_withPartition(iBins,iComp) = Kappa_Raoult_Kuwata(iComp) * Fbulk(iBins,iComp);
            
            S(iBins,iComp) = (D_m(iBins)^3 - Ddry_m^3) / ...
                (D_m(iBins)^3 - Ddry_m^3 * (1 - Kappa_withPartition(iBins,iComp)))...
                * exp(A_withPartition_m /D_m(iBins));
            
            S(1,:) = nan; % remove first point


            
        end
        
        
    end
 
    [Sc,MaxIndex] = max(S(:,iComp));
    
    Kappa_withPartition_CriticalPoint(iComp) = Kappa_withPartition(MaxIndex,iComp);
    % Kappa is calculated at each D_m.  Kappa value at the point of
    % activation is the final result.


end

Kappa_withPartition_CriticalPoint(Kappa_withPartition_CriticalPoint<1e-3) = 1e-3;
% Practically not CCN active if kappa < 1e-3
Kappa_UNIFAC = PKZ16(:,7);
Kappa_UNIFAC(Kappa_UNIFAC<1e-3) = 1e-3;




Fig1 = figure;
Fig1.Units = 'normalized';
Fig1.Position = [0.5 0.3 0.2 0.3];

loglog(PKZ16(:,6),Kappa_UNIFAC,'ro','MarkerSize',8); % UNIFAC by Petters et al.
hold on

loglog(PKZ16(:,6),Kappa_Raoult_Kuwata,'b^','MarkerSize',7) % Entirely soluble, water surface tension
loglog(PKZ16(:,6),Kappa_withPartition_CriticalPoint,'ks','MarkerFaceColor','y')% Full partition, calculated surface tension
loglog([1e-5 1],[1e-5 1],'k-');% 1:1 line
ErrorRange = 1;
loglog([1e-5 1],[1e-5 1]*(1+ErrorRange),'k--');
loglog([1e-5 1],[1e-5 1]/(1+ErrorRange),'k--');
ax1 = gca;
legend('Petters et al. (UNIFAC)','Entirely soluble','w/ solubility and surface','Location','northwest');


% Fig2 = figure;
% Fig2.Units = 'normalized';
% Fig2.Position = [0.7 0.5 0.2 0.5];
% ax2 = subplot(2,1,1);
% ax3 = subplot(2,1,2);
% 
% semilogx(ax2,D_m * 1e9, S) % Kohler curve
% %hold on
% semilogx(ax3,D_m * 1e9, Sigma_withPartition_J_per_m2)


% Plot glutaric acid phase separation as an example
% Fig3 = figure;
% Fig3.Units = 'normalized';
% Fig3.Position = [0.7 0.1 0.2 0.3];
% axis auto
% ax4 = gca;
% h = area(ax4, D_m * 1e9, [Fcore(:,6) Fbulk(:,6) Fsurf(:,6)]);
% set (ax4, 'Xscale', 'log');
% h(1).FaceColor = [.5 .5 .5];
% h(2).FaceColor = 'c';
% h(3).FaceColor = 'y';
% legend('Core','Bulk','Surface','Location','southeast');


LineWidth = 2;
FontSize = 15;
ax1.FontSize = FontSize;
ax1.LineWidth = LineWidth;
% ax2.FontSize = FontSize;
% ax2.LineWidth = LineWidth;
% ax3.FontSize = FontSize;
% ax3.LineWidth = LineWidth;
% ax4.FontSize = FontSize;
% ax4.LineWidth = LineWidth;


xlim(ax1,[1e-3 1e0])
% xlim(ax2,[50 5000])
% xlim(ax3,[50 5000])
% xlim(ax4,[50 5000])
ylim(ax1,[1e-3 1e0])
% ylim(ax2,[0.8 1.03])
% ylim(ax3,[0.04 0.075])
% ylim(ax4,[0 1])


xlabel(ax1,'Observed \kappa')
% xlabel(ax2,'Droplet diameter [nm]')
% xlabel(ax3,'Droplet diameter [nm]')
% xlabel(ax4,'Droplet diameter [nm]')


ylabel(ax1,'Model \kappa')
% ylabel(ax2,'Saturation ratio')
% ylabel(ax3,'Surface tension [J m^{-2}]')
% ylabel(ax4,'Phase fraction')



end