function Fig4b()

% Run number is reduced to 20 to demonstrate the code quickly

close all

Param = SetParam();
Const = GetConst();

% Reset parameters
Param.InorgSeed_VolFrac= 0.1; % Volume fraction of inorganic seed particles
Param.InorgKappa = 0.61; % ammonium sulfate, Petters and Kreidenweis 2007
Param.T_K = 298.15; % Temp dependence not fully implemented. Use only 298.15 K for now.
Param.Ddry_nm = 100;
DeltaROG_ug_per_m3 = [1000 100 10]';


% Define Monte Carlo parameter ranges
RunNumber = 20; % INCREASE THIS NUMBER TO PERFORM MORE MONTE CARLO RUNS
Gamma_min_mol_per_m2 = 3e-7; 
Gamma_max_mol_per_m2 = 7e-6;
K_min = 2;
K_max = 6e4;

% Make randomized parameters
% 95% interval is assumed to correspond to two-sigma of a normal
% distribution.  Therefore, 4 x sigma = max - min. 
% Parameters are assumed to be normal in log-scale.
% By no means these are established ranges.  These are for providing a sense
% of uncertainty range of the framework based on plausible ranges of
% individual parameters.

% Surface activity
mu_logGamma = 1/2 * log10(Gamma_min_mol_per_m2 * Gamma_max_mol_per_m2);
sigma_logGamma = (log10(Gamma_max_mol_per_m2) ...
    - log10(Gamma_min_mol_per_m2))/4; % Assume "max" to average is 2 sigma 
logGamma_rand = mu_logGamma + randn(RunNumber,1)*sigma_logGamma;
Gamma_mol_per_m2_rand = 10.^(logGamma_rand);

mu_logK = 1/2 * log10(K_max * K_min);
sigma_logK = (log10(K_max) - log10(K_min))/4;
logK_rand = mu_logK + randn(RunNumber,1) * sigma_logK;
K_rand = 10.^(logK_rand);


nO2CBins = size(Param.OM_2DVBS,1);
nCStarBins = size(Param.OM_2DVBS,2); % number of C* bins
% O/C Monte Carlo factor
% Assume the ratio of measured O/C to true O/C is within a factor of 1.3 for 2-sigma.
% Assume normal distribution in log scale.
sigma_logO2C_Factor = 0.5 * log10(1.3);
logO2C_Factor = randn(RunNumber,nO2CBins) * sigma_logO2C_Factor;
O2C_Factor_rand = 10.^logO2C_Factor;

% C* Monte Carlo factor
% Assume C* varies by a factor of 10 (1 bin) for 1-sigma.
sigma_logCstar_Factor = 1;
logCstar_Factor = randn(RunNumber,nCStarBins) * sigma_logCstar_Factor;
Cstar_Factor_rand = 10.^logCstar_Factor;


% Intrinsic kappa Monte Carlo factor
% Assume Predicted kappa is within a factor of two (0.5 ~ 2.0) for 2-sigma.
% Assume normal distribution in log scale.
% log(K_i/K_mu) varies between -log2 and log2, with sigma = 0.5 * log2.

sigma_logKappaFactor = 0.5 * log10(2); % two sigma within factor of 0.5 ~ 2.0
logKappaFactor = randn(RunNumber,nO2CBins,nCStarBins) * sigma_logKappaFactor; 
KappaFactor_rand = 10.^logKappaFactor; % Intrinsic kappa in each 2D-VBS bin will be varied

% Solubility Monte Carlo factor
% Assume Solubility varies by a factor of 10 (1 bin) for 1-sigma.
sigma_logC_v_per_v = 1;
logC_v_per_v_Factor = randn(RunNumber,nO2CBins) * sigma_logC_v_per_v;
C_v_per_v_Factor_rand = 10.^logC_v_per_v_Factor;



% Arrays for storing results
nROG_bins = size(DeltaROG_ug_per_m3,1);
ApparentKappaOrg_Result = zeros(nROG_bins,RunNumber);
ApparentKappaOrg_solubilityOnly_Result = zeros(nROG_bins,RunNumber);
IntrinsicKappaOrg_Result = zeros(nROG_bins,RunNumber);
O2C_Result = zeros(nROG_bins,RunNumber);
SortedIntrinsicKappaOrg_Result = zeros(nROG_bins,RunNumber);
SortedKappaOrgSolOnly_Result = zeros(nROG_bins,RunNumber);
SortedApparentKappaOrg_Result = zeros(nROG_bins,RunNumber);
KappaInt_25percentile = zeros(nROG_bins,1);
KappaInt_50percentile = zeros(nROG_bins,1);
KappaInt_75percentile = zeros(nROG_bins,1);
KappaSolOnly_25percentile = zeros(nROG_bins,1);
KappaSolOnly_50percentile = zeros(nROG_bins,1);
KappaSolOnly_75percentile = zeros(nROG_bins,1);
KappaFull_25percentile = zeros(nROG_bins,1);
KappaFull_50percentile = zeros(nROG_bins,1);
KappaFull_75percentile = zeros(nROG_bins,1);
%KappaFactor_loop = zeros(nO2CBins,nCStarBins);


for iMC = 1:RunNumber % Monte Carlo loop
    
    
    % Surfactant parameters
    Param.Gamma_mol_per_m2 = Gamma_mol_per_m2_rand(iMC);
    Param.K = K_rand(iMC);
    
    
    for iROG = 1:nROG_bins;
        
        
        % Vary O/C bins
         O2CBasis_Factor_loop = squeeze(O2C_Factor_rand(iMC,:));
         Param.O2CBasis_Factor_rand = O2CBasis_Factor_loop; 
         
         % Vary Cstar bins
         Cstar_Factor_loop = squeeze(Cstar_Factor_rand(iMC,:));
         Param.CstarBasis_Factor_rand = Cstar_Factor_loop;
         
         % Vary solubility
         C_v_per_v_Factor_loop = squeeze(C_v_per_v_Factor_rand(iMC,:));
         Param.C_v_per_v_Factor_rand = C_v_per_v_Factor_loop;

        
        
        Param.Delta_aP_ug_per_m3 = DeltaROG_ug_per_m3(iROG); % Amount of reacted ROG (ug/m3)
        Param.Delta_aP_ugC_per_m3 = Param.Delta_aP_ug_per_m3 * Param.aP_OC2OM;
        Param.OC_2DVBS = Param.Delta_aP_ugC_per_m3 * Param.OCyield_2DVBS; % Reacted a-pinene C * OC yield in 2D
        % Convert OC VBS to OM VBS
        O2C = Param.O2CBasis;  % make O/C vector for readability
        OM2OC = 1 + 1/12*(2 - O2C) + 16/12 * O2C; % Ref: Donahue et al.(2012), Heald et al. (2010)
        for i_O2C = 1:size(O2C)
            Param.OM_2DVBS(i_O2C,:) = Param.OC_2DVBS(i_O2C,:) * OM2OC(i_O2C); % Note OM = PM + gas
        end
        % Construct 1D VBS
        Param.VBS = sum(Param.OM_2DVBS); % OM = PM + gas
        
        
        
        
        Result = CalcIntrinsicKappa2DVBS(Param,Const);
        
        % Vary Intrinsic Kappa
        KappaFactor_loop = squeeze(KappaFactor_rand(iMC,:,:)); % 3D into 2D
        Result.IntrinsicKappa_2D = Result.IntrinsicKappa_2D ...
            .* KappaFactor_loop;
        VolumeWeightedKappa_2D = Result.IntrinsicKappa_2D .* Result.OrgPMvolFrac_2D;
        Result.IntrinsicKappa = sum(VolumeWeightedKappa_2D(:)); % volume averaged value
        
        
        Result = CalcApparentKappa(Param,Const,Result);
        
        ApparentKappaOrg_Result(iROG,iMC) = Result.ApparentKappaOrg;
        ApparentKappaOrg_solubilityOnly_Result(iROG,iMC) = Result.ApparentKappaOrg_solubilityOnly;
        IntrinsicKappaOrg_Result(iROG,iMC) = Result.IntrinsicKappa;
        
        O2C_Result(iROG,iMC) = Result.MassAveragedO2C;
        
        
        
    end % ROG loop

    
    Progress = iMC/RunNumber;
    
    if Progress == 0.1;
        disp('10% done with alpha-pinene')
    elseif Progress == 0.5;
        disp('50% done with alpha-pinene')
    end

    
    
end %Monte Carlo loop


% Sort results in percentitle

Index_25percentile = floor(0.25 * RunNumber);
Index_50percentile = floor(0.5 * RunNumber);
Index_75percentile = floor(0.75 * RunNumber);

% Intrinsic
for iROG = 1:nROG_bins
    MC_KappaInt_Result_loop = IntrinsicKappaOrg_Result(iROG,:); 
    SortedIntrinsicKappaOrg_Result(iROG,:) = sort(MC_KappaInt_Result_loop);
    KappaInt_25percentile(iROG) = SortedIntrinsicKappaOrg_Result(iROG,Index_25percentile);
    KappaInt_50percentile(iROG) = SortedIntrinsicKappaOrg_Result(iROG,Index_50percentile);
    KappaInt_75percentile(iROG) = SortedIntrinsicKappaOrg_Result(iROG,Index_75percentile);   
    
end

% Solubility only
for iROG = 1:nROG_bins
    MC_KappaSolOnly_Result_loop = ApparentKappaOrg_solubilityOnly_Result(iROG,:); 
    SortedKappaOrgSolOnly_Result(iROG,:) = sort(MC_KappaSolOnly_Result_loop);
    KappaSolOnly_25percentile(iROG) = SortedKappaOrgSolOnly_Result(iROG,Index_25percentile);
    KappaSolOnly_50percentile(iROG) = SortedKappaOrgSolOnly_Result(iROG,Index_50percentile);
    KappaSolOnly_75percentile(iROG) = SortedKappaOrgSolOnly_Result(iROG,Index_75percentile);   
    
end

% Full partition
for iROG = 1:nROG_bins
    MC_KappaFull_Result_loop = ApparentKappaOrg_Result(iROG,:); 
    SortedApparentKappaOrg_Result(iROG,:) = sort(MC_KappaFull_Result_loop);
    KappaFull_25percentile(iROG) = SortedApparentKappaOrg_Result(iROG,Index_25percentile);
    KappaFull_50percentile(iROG) = SortedApparentKappaOrg_Result(iROG,Index_50percentile);
    KappaFull_75percentile(iROG) = SortedApparentKappaOrg_Result(iROG,Index_75percentile);   
    
end



% Identical approach for another 2D-VBS dataset from Murphy et al. (Aged
% ambient)

DeltaROG_ug_per_m3_Murphy = [1000 100 10]';


% Arrays for storing results
nROG_bins_Murphy = size(DeltaROG_ug_per_m3_Murphy,1);
ApparentKappaOrg_Result_Murphy = zeros(nROG_bins_Murphy,RunNumber);
ApparentKappaOrg_solubilityOnly_Result_Murphy = zeros(nROG_bins_Murphy,RunNumber);
IntrinsicKappaOrg_Result_Murphy = zeros(nROG_bins_Murphy,RunNumber);
O2C_Result_Murphy = zeros(nROG_bins_Murphy,RunNumber);
SortedIntrinsicKappaOrg_Result_Murphy = zeros(nROG_bins_Murphy,RunNumber);
SortedKappaOrgSolOnly_Result_Murphy = zeros(nROG_bins_Murphy,RunNumber);
SortedApparentKappaOrg_Result_Murphy = zeros(nROG_bins_Murphy,RunNumber);
KappaInt_25percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaInt_50percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaInt_75percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaSolOnly_25percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaSolOnly_50percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaSolOnly_75percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaFull_25percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaFull_50percentile_Murphy = zeros(nROG_bins_Murphy,1);
KappaFull_75percentile_Murphy = zeros(nROG_bins_Murphy,1);
%KappaFactor_loop = zeros(nO2CBins,nCStarBins);


for iMC = 1:RunNumber % Monte Carlo loop
    
    
    % Surfactant parameters
    Param.Gamma_mol_per_m2 = Gamma_mol_per_m2_rand(iMC);
    Param.K = K_rand(iMC);
    
    
    for iROG_Murphy = 1:nROG_bins_Murphy;
        
        
        % Vary O/C bins
         O2CBasis_Factor_loop = squeeze(O2C_Factor_rand(iMC,:));
         Param.O2CBasis_Factor_rand = O2CBasis_Factor_loop; 
         
         % Vary Cstar bins
         Cstar_Factor_loop = squeeze(Cstar_Factor_rand(iMC,:));
         Param.CstarBasis_Factor_rand = Cstar_Factor_loop;
         

        Param.OM_2DVBS = DeltaROG_ug_per_m3_Murphy(iROG_Murphy) * Param.OM_2DVBS_yield_Murphy;

        % Construct 1D VBS
        Param.VBS = sum(Param.OM_2DVBS); % OM = PM + gas
        
        
        
        
        Result = CalcIntrinsicKappa2DVBS(Param,Const);
        
        % Vary Intrinsic Kappa
        KappaFactor_loop = squeeze(KappaFactor_rand(iMC,:,:)); % 3D into 2D
        Result.IntrinsicKappa_2D = Result.IntrinsicKappa_2D ...
            .* KappaFactor_loop;
        VolumeWeightedKappa_2D = Result.IntrinsicKappa_2D .* Result.OrgPMvolFrac_2D;
        Result.IntrinsicKappa = sum(VolumeWeightedKappa_2D(:)); % volume averaged value
        
        
        Result = CalcApparentKappa(Param,Const,Result);
        
        ApparentKappaOrg_Result_Murphy(iROG_Murphy,iMC) = Result.ApparentKappaOrg;
        ApparentKappaOrg_solubilityOnly_Result_Murphy(iROG_Murphy,iMC) = Result.ApparentKappaOrg_solubilityOnly;
        IntrinsicKappaOrg_Result_Murphy(iROG_Murphy,iMC) = Result.IntrinsicKappa;
        
        O2C_Result_Murphy(iROG_Murphy,iMC) = Result.MassAveragedO2C;
        
        
        
    end % ROG loop

    
    Progress = iMC/RunNumber;
    
    if Progress == 0.1;
        disp('10% done with Murphy et al. 2D-VBS')
    elseif Progress == 0.5;
        disp('50% done with Murphy et al. 2D-VBS')
    end

    
    
end %Monte Carlo loop


% Sort results

% Intrinsic
for iROG_Murphy = 1:nROG_bins_Murphy
    MC_KappaInt_Result_loop_Murphy = IntrinsicKappaOrg_Result_Murphy(iROG_Murphy,:); 
    SortedIntrinsicKappaOrg_Result_Murphy(iROG_Murphy,:) = sort(MC_KappaInt_Result_loop_Murphy);
    KappaInt_25percentile_Murphy(iROG_Murphy) = SortedIntrinsicKappaOrg_Result_Murphy(iROG_Murphy,Index_25percentile);
    KappaInt_50percentile_Murphy(iROG_Murphy) = SortedIntrinsicKappaOrg_Result_Murphy(iROG_Murphy,Index_50percentile);
    KappaInt_75percentile_Murphy(iROG_Murphy) = SortedIntrinsicKappaOrg_Result_Murphy(iROG_Murphy,Index_75percentile);   
    
end

% Solubility only
for iROG_Murphy = 1:nROG_bins_Murphy
    MC_KappaSolOnly_Result_loop_Murphy = ApparentKappaOrg_solubilityOnly_Result_Murphy(iROG_Murphy,:); 
    SortedKappaOrgSolOnly_Result_Murphy(iROG_Murphy,:) = sort(MC_KappaSolOnly_Result_loop_Murphy);
    KappaSolOnly_25percentile_Murphy(iROG_Murphy) = SortedKappaOrgSolOnly_Result_Murphy(iROG_Murphy,Index_25percentile);
    KappaSolOnly_50percentile_Murphy(iROG_Murphy) = SortedKappaOrgSolOnly_Result_Murphy(iROG_Murphy,Index_50percentile);
    KappaSolOnly_75percentile_Murphy(iROG_Murphy) = SortedKappaOrgSolOnly_Result_Murphy(iROG_Murphy,Index_75percentile);   
    
end

% Full partition
for iROG_Murphy = 1:nROG_bins_Murphy
    MC_KappaFull_Result_loop_Murphy = ApparentKappaOrg_Result_Murphy(iROG_Murphy,:); 
    SortedApparentKappaOrg_Result_Murphy(iROG_Murphy,:) = sort(MC_KappaFull_Result_loop_Murphy);
    KappaFull_25percentile_Murphy(iROG_Murphy) = SortedApparentKappaOrg_Result_Murphy(iROG_Murphy,Index_25percentile);
    KappaFull_50percentile_Murphy(iROG_Murphy) = SortedApparentKappaOrg_Result_Murphy(iROG_Murphy,Index_50percentile);
    KappaFull_75percentile_Murphy(iROG_Murphy) = SortedApparentKappaOrg_Result_Murphy(iROG_Murphy,Index_75percentile);   
    
end








% Plot results
close all
LineWidth = 2;
FontSize = 15;

Fig1 = figure;
Fig1.Units = 'normalized';
Fig1.Position = [0.5 0.3 0.2 0.3];

x_O2C_temp = O2C_Result(:,1);

pInt = plot(x_O2C_temp,KappaInt_50percentile,'k-','LineWidth',LineWidth+1);
ax = gca;
hold (ax,'on')
pInt25 = plot(x_O2C_temp,KappaInt_25percentile,'k--','LineWidth',LineWidth);
pInt75 = plot(x_O2C_temp,KappaInt_75percentile,'k--','LineWidth',LineWidth);


pSolOnly = plot(x_O2C_temp,KappaSolOnly_50percentile,'b-','LineWidth',LineWidth+1);
pSolOnly25 = plot(x_O2C_temp,KappaSolOnly_25percentile,'b--','LineWidth',LineWidth);
pSolOnly75 = plot(x_O2C_temp,KappaSolOnly_75percentile,'b--','LineWidth',LineWidth);



pFull = plot(x_O2C_temp,KappaFull_50percentile,'r-','LineWidth',LineWidth+1);
plot(x_O2C_temp,KappaFull_25percentile,'r--','LineWidth',LineWidth)
plot(x_O2C_temp,KappaFull_75percentile,'r--','LineWidth',LineWidth)



% add Rickard et al. line
Gradient_plus = 0.147+0.01;
Gradient_minus = 0.147-0.01;
Intercept_plus = 0.0306+0.0131;
Intercept_minus = 0.0306-0.0131;
x_O2C = [0 1];
Rickard_plus = Gradient_plus * x_O2C + Intercept_plus;
Rickard_minus = Gradient_minus * x_O2C + Intercept_minus;
pRickard = patch([0 1 1 0],...
    [Rickard_minus(1) Rickard_minus(2) Rickard_plus(2) Rickard_plus(1)],...
    [.5 .5 .5],'EdgeColor','none','FaceAlpha',0.5);
uistack(pRickard,'bottom')

legend([pInt pSolOnly pFull],'Intrinsic','Solubility only','Full partition','Location','northwest')

xlim([0 0.8]);
ylim([0 0.2]);

ax.FontSize = FontSize;
ax.LineWidth = LineWidth;

xlabel('O/C')
ylabel('\kappa')



x_O2C_temp_Murphy = O2C_Result_Murphy(:,1);
pInt_Murphy = plot(x_O2C_temp_Murphy,KappaInt_50percentile_Murphy,'k-','LineWidth',LineWidth+1);
plot(x_O2C_temp_Murphy,KappaInt_25percentile_Murphy,'k--','LineWidth',LineWidth);
plot(x_O2C_temp_Murphy,KappaInt_75percentile_Murphy,'k--','LineWidth',LineWidth);


pSolOnly_Murphy = plot(x_O2C_temp_Murphy,KappaSolOnly_50percentile_Murphy,'b-','LineWidth',LineWidth+1);
plot(x_O2C_temp_Murphy,KappaSolOnly_25percentile_Murphy,'b--','LineWidth',LineWidth);
plot(x_O2C_temp_Murphy,KappaSolOnly_75percentile_Murphy,'b--','LineWidth',LineWidth);



pFull_Murphy = plot(x_O2C_temp_Murphy,KappaFull_50percentile_Murphy,'r-','LineWidth',LineWidth+1);
plot(x_O2C_temp_Murphy,KappaFull_25percentile_Murphy,'r--','LineWidth',LineWidth)
plot(x_O2C_temp_Murphy,KappaFull_75percentile_Murphy,'r--','LineWidth',LineWidth)




end