function FigS1()
% Calculate Kohler curve based on a range of parameters


close all
Const = GetConst;
Param = SetParam;

% Basic parameter
Ddry_m = 100e-9;
Kappa_NP = 0.1; % kappa without surfactant partitioning
SigmaMin_J_per_m2 = 0.04; % arbiturarily chosen minimum surface tension

MolarVol_m3_per_mol_H2O = 18.02e-3 /(1000);
A_m_w = 4 * MolarVol_m3_per_mol_H2O * Const.Sigma_H2O_J_per_m2...
    /(Const.R_J_per_mol_K * Param.T_K); % assuming water surface tension



% Make droplet arrays
Nbins = 100;
Dmax_m = 5000e-9;
D_m = logspace(log10(Ddry_m),log10(Dmax_m),Nbins)';

% Define parameter ranges
Gamma_min_mol_per_m2 = 3e-7; 
Gamma_max_mol_per_m2 = 7e-6;
K_min = 2;
K_max = 6e4;
RunNumber = 1000;

% Make probability distribution functions

mu_logGamma = 1/2 * log10(Gamma_min_mol_per_m2 * Gamma_max_mol_per_m2);
sigma_logGamma = (log10(Gamma_max_mol_per_m2) ...
    - log10(Gamma_min_mol_per_m2))/4; % Assume "max" to average is 2 sigma 
logGamma_rand = mu_logGamma + randn(RunNumber,1)*sigma_logGamma;


Gamma_mol_per_m2_rand = 10.^(logGamma_rand);

mu_logK = 1/2 * log10(K_max * K_min);
sigma_logK = (log10(K_max) - log10(K_min))/4;
logK_rand = mu_logK + randn(RunNumber,1) * sigma_logK;
K_rand = 10.^(logK_rand);



% Arrays for storing results
BulkFrac = zeros(Nbins,RunNumber); % Ratio of bulk solute to total solute
Sc = zeros(RunNumber,1);
KappaApparent = zeros(RunNumber,1);

for iMC = 1:RunNumber
    
    Results = CalcBulkFrac(Ddry_m,D_m,1,Kappa_NP,Gamma_mol_per_m2_rand(iMC)...
        ,K_rand(iMC));
    
    BulkFrac(:,iMC)=Results.BulkFrac;
    
    Sigma_J_per_m2_P(:,iMC) = Const.Sigma_H2O_J_per_m2...
        - Const.R_J_per_mol_K * Param.T_K ...
        * Gamma_mol_per_m2_rand(iMC)...
        * log(1 + K_rand(iMC) * Results.x_bulk_solute);
    
    A_m_P(:,iMC) = 4 * MolarVol_m3_per_mol_H2O .* Sigma_J_per_m2_P(:,iMC)...
        /(Const.R_J_per_mol_K * Param.T_K);
    
    Kappa_P(:,iMC) = Results.BulkFrac * Kappa_NP;
    
    S_aP_sigmaP(:,iMC) = (D_m.^3 - Ddry_m^3) ./ (D_m.^3 - Ddry_m^3 * (1-Kappa_P(:,iMC)))...
    .* exp(A_m_P(:,iMC)./D_m);

    Sc(iMC) = max(S_aP_sigmaP(:,iMC));
    KappaApparent(iMC) = Sc_and_Ddry_2_kappa(Sc(iMC),A_m_w,Ddry_m);
    
    
    if iMC == RunNumber/2
       disp('50% done') 
    end
    
end


Sigma_J_per_m2_P ... % P: with partitioning
    (Sigma_J_per_m2_P < SigmaMin_J_per_m2)=...
    SigmaMin_J_per_m2; % limit sigma minimum

S_aNP_sigmaW = (D_m.^3 - Ddry_m^3) ./ (D_m.^3 - Ddry_m^3 * (1-Kappa_NP))...
    .* exp(A_m_w./D_m); % no partition in Raoult, water sigma


% Make plots
Fig1 = figure;
LineWidth = 2;
FontSize = 15;
Dmax_m = 2e-6;
Fig1.Units = 'normalized';
Fig1.Position = [0.5 0.3 0.2 0.6];
ax1 = subplot(3,1,1);
ax2 = subplot(3,1,2);
ax3 = subplot(3,1,3);
linkaxes([ax1,ax2,ax3],'x')
xlabel(ax3,'Wet diameter [\mum]')

plot(ax1,D_m * 1e6, S_aP_sigmaP)



ylabel(ax1,'Saturation ratio')
ylabel(ax2,'Fraction of solute in bulk')
ylabel(ax3,'Surface tension [J m^{-2}]')

ylim(ax1,[1 1.005])
ylim(ax2,[0 1])
ylim(ax3,[SigmaMin_J_per_m2 0.075])

xlim(ax1,[Ddry_m * 1e6 Dmax_m * 1e6])

hold (ax1,'on')
hold (ax2,'on')
hold (ax3,'on')


ax1.FontSize = FontSize;
ax1.LineWidth = LineWidth;
ax2.FontSize = FontSize;
ax2.LineWidth = LineWidth;
ax3.FontSize = FontSize;
ax3.LineWidth = LineWidth;
box(ax2,'on')
box(ax3,'on')

p1 = plot(ax1,D_m * 1e6, S_aNP_sigmaW,'c-','LineWidth',LineWidth+1);
plot(ax2,D_m * 1e6, BulkFrac);
plot(ax2,[Ddry_m * 1e6 Dmax_m * 1e6],...
    [1 1], 'c-','LineWidth',LineWidth+1);
plot(ax3,D_m * 1e6, Sigma_J_per_m2_P);
plot(ax3,[Ddry_m * 1e6 Dmax_m * 1e6],...
    [Const.Sigma_H2O_J_per_m2 Const.Sigma_H2O_J_per_m2], 'c-'...
    ,'LineWidth',LineWidth+1);

legend(p1,'No partitioning, \sigma_{w}');

Fig2 = figure;
Fig2.Units = 'normalized';
Fig2.Position = [0.7 0.3 0.2 0.6];
ax1 = subplot(3,1,1);
ax2 = subplot(3,1,2);
ax3 = subplot(3,1,3);

ylabel(ax1,'Probability')
ylabel(ax2,'Probability')
ylabel(ax3,'Probability')
xlabel(ax1,'Apparent Kappa')
xlabel(ax2,'log \Gamma^{max\prime}')
xlabel(ax3,'log K^{\prime}')

hold (ax1,'on')
hold (ax2,'on')
hold (ax3,'on')

ax1.FontSize = FontSize;
ax1.LineWidth = LineWidth;
ax2.FontSize = FontSize;
ax2.LineWidth = LineWidth;
ax3.FontSize = FontSize;
ax3.LineWidth = LineWidth;
box(ax1,'on')
box(ax2,'on')
box(ax3,'on')


h1 = histogram(ax1, KappaApparent,20,'Normalization','probability');
h1.FaceColor = 'r';
histogram(ax2, logGamma_rand, 10,'Normalization','probability')
histogram(ax3, logK_rand, 10,'Normalization','probability')


end