function Results = Topping_BulkFrac(Ddry_m)

% Calculate bulk fraction of equimolar mixture example in Topping 2010
% Table 1


close all

%Const
R_J_per_mol_K = 8.314;
SigmaH2O_J_per_m2 = 0.072; % surface tension of water

% Basic parameters
T_K = 298.15;
SigmaMin_J_per_m2 = 0.03; %Assumed minimum sigma


% Make droplet arrays
Dmax_m = 5000e-9;
D_m = logspace(log10(Ddry_m),log10(Dmax_m),100)';
Vol_m3 = pi/6 * D_m.^3;
Area_m2 = pi * D_m.^2; 

% Parameter definitions follow Topping 2010.
Gamma_mol_per_m2_malic = 5.8e-6;
Gamma_mol_per_m2_cis_pinonic = 2.6e-6;
Gamma_mol_per_m2_malonic = 3.3e-6;
Gamma_mol_per_m2_glutaric = 5e-7;
Gamma_mol_per_m2_SRfulvic = 2.5e-6;

K_malic = 22.8; % adsorption equilibrium constant, dimensionless (1/activity)
K_cis_pinonic = 2.62e4;
K_malonic = 57.65;
K_glutaric = 1045.94;
K_SRfulvic = 35942.03;

Morg_kg_per_mol_malic = 134.09e-3;
Morg_kg_per_mol_cis_pinonic = 184.23e-3;
Morg_kg_per_mol_malonic = 104.06e-3;
Morg_kg_per_mol_glutaric = 132.11e-3;
Morg_kg_per_mol_SRfulvic = 732.59e-3;

Density_kg_per_m3_malic = 1609;
Density_kg_per_m3_cis_pinonic = 786;
Density_kg_per_m3_malonic = 1630;
Density_kg_per_m3_glutaric = 1316;
Density_kg_per_m3_SRfulvic = 1400;

MolarVol_m3_per_mol_malic = Morg_kg_per_mol_malic / Density_kg_per_m3_malic;
MolarVol_m3_per_mol_cis_pinonic = Morg_kg_per_mol_cis_pinonic / Density_kg_per_m3_cis_pinonic;
MolarVol_m3_per_mol_malonic = Morg_kg_per_mol_malonic / Density_kg_per_m3_malonic;
MolarVol_m3_per_mol_glutaric = Morg_kg_per_mol_glutaric / Density_kg_per_m3_glutaric;
MolarVol_m3_per_mol_SRfulvic = Morg_kg_per_mol_SRfulvic / Density_kg_per_m3_SRfulvic;
MolarVol_m3_per_mol_H2O = 18.02e-3 / 1e3;

% equimolar mixture of five components
Total_MolarVol_m3_per_mol = 1/5 * (... 
    MolarVol_m3_per_mol_malic + ...
    MolarVol_m3_per_mol_cis_pinonic + ...
    MolarVol_m3_per_mol_malonic + ...
    MolarVol_m3_per_mol_glutaric + ...
    MolarVol_m3_per_mol_SRfulvic);

% Calculate volume fractions for using Kappa-Kohler later
VolFrac_malic = 1/5 * MolarVol_m3_per_mol_malic /...
    Total_MolarVol_m3_per_mol;
VolFrac_cis_pinonic = 1/5 * MolarVol_m3_per_mol_cis_pinonic /...
    Total_MolarVol_m3_per_mol;
VolFrac_malonic = 1/5 * MolarVol_m3_per_mol_malonic /...
    Total_MolarVol_m3_per_mol;
VolFrac_glutaric = 1/5 * MolarVol_m3_per_mol_glutaric /...
    Total_MolarVol_m3_per_mol;
VolFrac_SRfulvic = 1/5 * MolarVol_m3_per_mol_SRfulvic /...
    Total_MolarVol_m3_per_mol;

% mol of each solute should be equal in the equimolar example
n_mol_malic = pi/6 * Ddry_m^3 * VolFrac_malic / MolarVol_m3_per_mol_malic;
n_mol_cis_pinonic = pi/6 * Ddry_m^3 * VolFrac_cis_pinonic / MolarVol_m3_per_mol_cis_pinonic;
n_mol_malonic = pi/6 * Ddry_m^3 * VolFrac_malonic / MolarVol_m3_per_mol_malonic;
n_mol_glutaric = pi/6 * Ddry_m^3 * VolFrac_glutaric / MolarVol_m3_per_mol_glutaric;
n_mol_SRfulvic = pi/6 * Ddry_m^3 * VolFrac_SRfulvic / MolarVol_m3_per_mol_SRfulvic;
n_mol_H2O = (Vol_m3 - pi/6 * Ddry_m^3) / MolarVol_m3_per_mol_H2O;


% Surfactant partitioning 
% Malic
a_mol_malic = Area_m2 * Gamma_mol_per_m2_malic * K_malic...
    - n_mol_H2O * K_malic...
    - n_mol_malic * K_malic;

b_mol_malic = n_mol_malic * K_malic...
    - n_mol_malic - n_mol_H2O...
    - Area_m2 * Gamma_mol_per_m2_malic * K_malic;

x_bulk_malic = (-b_mol_malic - (b_mol_malic.^2 - 4 * a_mol_malic...
    * n_mol_malic).^0.5) ./ (2 * a_mol_malic);

n_bulk_mol_malic = x_bulk_malic .* n_mol_H2O ./(1 - x_bulk_malic);
% treat the mixture as if binary (Topping 2010 eq.19)
BulkFrac_malic = n_bulk_mol_malic / n_mol_malic;


% cis-pinonic
a_mol_cis_pinonic = Area_m2 * Gamma_mol_per_m2_cis_pinonic * K_cis_pinonic...
    - n_mol_H2O * K_cis_pinonic...
    - n_mol_cis_pinonic * K_cis_pinonic;

b_mol_cis_pinonic = n_mol_cis_pinonic * K_cis_pinonic...
    - n_mol_cis_pinonic - n_mol_H2O...
    - Area_m2 * Gamma_mol_per_m2_cis_pinonic * K_cis_pinonic;

x_bulk_cis_pinonic = (-b_mol_cis_pinonic - (b_mol_cis_pinonic.^2 - 4 * a_mol_cis_pinonic...
    * n_mol_cis_pinonic).^0.5) ./ (2 * a_mol_cis_pinonic);

n_bulk_mol_cis_pinonic = x_bulk_cis_pinonic .* n_mol_H2O ./(1 - x_bulk_cis_pinonic);
BulkFrac_cis_pinonic = n_bulk_mol_cis_pinonic / n_mol_cis_pinonic;

% malonic
a_mol_malonic = Area_m2 * Gamma_mol_per_m2_malonic * K_malonic...
    - n_mol_H2O * K_malonic...
    - n_mol_malonic * K_malonic;

b_mol_malonic = n_mol_malonic * K_malonic...
    - n_mol_malonic - n_mol_H2O...
    - Area_m2 * Gamma_mol_per_m2_malonic * K_malonic;

x_bulk_malonic = (-b_mol_malonic - (b_mol_malonic.^2 - 4 * a_mol_malonic...
    * n_mol_malonic).^0.5) ./ (2 * a_mol_malonic);

n_bulk_mol_malonic = x_bulk_malonic .* n_mol_H2O ./(1 - x_bulk_malonic);
BulkFrac_malonic = n_bulk_mol_malonic / n_mol_malonic;

% glutaric
a_mol_glutaric = Area_m2 * Gamma_mol_per_m2_glutaric * K_glutaric...
    - n_mol_H2O * K_glutaric...
    - n_mol_glutaric * K_glutaric;

b_mol_glutaric = n_mol_glutaric * K_glutaric...
    - n_mol_glutaric - n_mol_H2O...
    - Area_m2 * Gamma_mol_per_m2_glutaric * K_glutaric;

x_bulk_glutaric = (-b_mol_glutaric - (b_mol_glutaric.^2 - 4 * a_mol_glutaric...
    * n_mol_glutaric).^0.5) ./ (2 * a_mol_glutaric);

n_bulk_mol_glutaric = x_bulk_glutaric .* n_mol_H2O ./(1 - x_bulk_glutaric);
BulkFrac_glutaric = n_bulk_mol_glutaric / n_mol_glutaric ; 

% SRfulvic acid
a_mol_SRfulvic = Area_m2 * Gamma_mol_per_m2_SRfulvic * K_SRfulvic...
    - n_mol_H2O * K_SRfulvic...
    - n_mol_SRfulvic * K_SRfulvic;

b_mol_SRfulvic = n_mol_SRfulvic * K_SRfulvic...
    - n_mol_SRfulvic - n_mol_H2O...
    - Area_m2 * Gamma_mol_per_m2_SRfulvic * K_SRfulvic;

x_bulk_SRfulvic = (-b_mol_SRfulvic - (b_mol_SRfulvic.^2 - 4 * a_mol_SRfulvic...
    * n_mol_SRfulvic).^0.5) ./ (2 * a_mol_SRfulvic);

n_bulk_mol_SRfulvic = x_bulk_SRfulvic .* n_mol_H2O ./(1 - x_bulk_SRfulvic);
BulkFrac_SRfulvic = n_bulk_mol_SRfulvic / n_mol_SRfulvic;


% Return results

Results.BulkFrac_malic = BulkFrac_malic;
Results.BulkFrac_cis_pinonic = BulkFrac_cis_pinonic;
Results.BulkFrac_malonic = BulkFrac_malonic;
Results.BulkFrac_glutaric = BulkFrac_glutaric;
Results.BulkFrac_SRfulvic = BulkFrac_SRfulvic;
Results.D_m = D_m;
Results.Vol_m3 = Vol_m3;
Results.VolFrac_malic = VolFrac_malic;
Results.VolFrac_cis_pinonic = VolFrac_cis_pinonic;
Results.VolFrac_malonic = VolFrac_malonic;
Results.VolFrac_glutaric = VolFrac_glutaric;
Results.VolFrac_SRfulvic = VolFrac_SRfulvic;
Results.SigmaH2O_J_per_m2 = SigmaH2O_J_per_m2;
Results.x_bulk_malic = x_bulk_malic;
Results.x_bulk_cis_pinonic = x_bulk_cis_pinonic;
Results.x_bulk_malonic = x_bulk_malonic;
Results.x_bulk_glutaric = x_bulk_glutaric;
Results.x_bulk_SRfulvic = x_bulk_SRfulvic;
Results.BulkFrac_malic = BulkFrac_malic;
Results.BulkFrac_cis_pinonic = BulkFrac_cis_pinonic;
Results.BulkFrac_malonic = BulkFrac_malonic;
Results.BulkFrac_glutaric = BulkFrac_glutaric;
Results.BulkFrac_SRfulvic = BulkFrac_SRfulvic;



end
